<?php

namespace Intergo\Helpers;

class StringHelper
{
    /**
     * @param $haystack
     * @param $needle
     * @return bool
     */
    public static function startsWith($haystack, $needle) {
        return strncmp($haystack, $needle, strlen($needle)) === 0;
    }

    /**
     * @param $haystack
     * @param $needle
     * @return bool
     */
    public static function endsWith($haystack, $needle) {
        return substr_compare($haystack, $needle, -strlen($needle)) === 0;
    }

    /**
     * Find the position of the first occurrence of an array of substrings in a string
     *
     * @param string $haystack The string to search in
     * @param array $needles The array of neededls.
     * If any needle is not a string, it is converted to an integer and applied as the ordinal value of a character.
     * @param integer $offset [optional] If specified, search will start this number of characters counted from the beginning of the string.
     * Unlike {@see strrpos()} and {@see strripos()}, the offset cannot be negative.
     * @return integer|false Returns the position where the needle exists relative to the beginnning of the haystack string (independent of search direction or offset). Also note that string positions start at 0, and not 1.
     * Returns FALSE if the needle was not found.
     */
    public static function strpos_in_array(string $haystack, array $needles, int $offset = 0)
    {
        foreach ($needles as $needle ) {
            $position = strpos($haystack, $needle, $offset);
            if ($position !== false) {
                return $position;
            }
        }
        return false;
    }
}